@@ -30,7 +30,6 @@ License version 3 and version 2.1 along with this program.  If not, see
 #include "listener.h"
 #include <dbus/dbus-glib-bindings.h>
 
-#include "../libindicate/indicate-interface-client.h"
 #include "../libindicate/listener-private.h"
 
 typedef enum _get_property_type get_property_type;
@@ -50,9 +49,11 @@ struct _get_property_t {
 };
 
 static void
-get_property_cb (DBusGProxy *proxy, GValue OUT_vvalue, GError *error, gpointer userdata)
+get_property_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 {
-	get_property_t * get_property_data = (get_property_t *)userdata;
+	get_property_t * get_property_data = (get_property_t *)user_data;
+	GError * error = NULL;
+	GVariant * retvalue = g_dbus_proxy_call_finish(G_DBUS_PROXY(object), res, &error);
 
 	if (error != NULL) {
 		g_warning("Unable to get property data: %s", error->message);
@@ -60,10 +61,12 @@ get_property_cb (DBusGProxy *proxy, GValue OUT_vvalue, GError *error, gpointer u
 		return;
 	}
 
+	GVariant * value = g_variant_get_child_value(retvalue, 0);
+
 	switch (get_property_data->type) {
 	case PROPERTY_TYPE_ICON: {
 		indicate_listener_get_property_icon_cb cb = (indicate_listener_get_property_icon_cb)get_property_data->cb;
-		const gchar * OUT_value = g_value_get_string(&OUT_vvalue);
+		const gchar * OUT_value = g_variant_get_string(value, NULL);
 
 		/* There is no icon */
 		if (OUT_value == NULL || OUT_value[0] == '\0') {
@@ -102,12 +105,16 @@ get_property_cb (DBusGProxy *proxy, GValue OUT_vvalue, GError *error, gpointer u
 	}
 	}
 
+	g_variant_unref(value);
 	g_free(get_property_data->property);
 	g_free(get_property_data);
 
 	return;
 };
 
+/* A small function to take the common list of parameters and
+   build a callback structure to hold them all.  Eventually we
+   get the data and unwind this structure. */
 static void
 get_property_helper (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, GCallback callback, gpointer data, get_property_type prop_type)
 {
@@ -122,7 +129,16 @@ get_property_helper (IndicateListener * listener, IndicateListenerServer * serve
 	get_property_data->property = g_strdup(property);
 	get_property_data->type = prop_type;
 	
-	org_ayatana_indicate_get_indicator_property_async (server->proxy , INDICATE_LISTENER_INDICATOR_ID(indicator), property, get_property_cb, get_property_data);
+	g_dbus_proxy_call(server->proxy,
+	                  "GetIndicatorProperty",
+	                  g_variant_new("(us)",
+	                                INDICATE_LISTENER_INDICATOR_ID(indicator), property),
+	                  G_DBUS_CALL_FLAGS_NONE,
+	                  -1, /* timeout */
+	                  NULL, /* cancel */
+	                  get_property_cb,
+	                  get_property_data);
+
 	return;
 }
 
