@@ -60,8 +60,8 @@ struct _IndicateIndicatorPrivate
 G_DEFINE_TYPE (IndicateIndicator, indicate_indicator, G_TYPE_OBJECT);
 
 static void indicate_indicator_finalize (GObject * object);
-static void set_property (IndicateIndicator * indicator, const gchar * key, const GValue * data);
-static const GValue * get_property (IndicateIndicator * indicator, const gchar * key);
+static void set_property (IndicateIndicator * indicator, const gchar * key, GVariant * data);
+static GVariant * get_property (IndicateIndicator * indicator, const gchar * key);
 static GPtrArray * list_properties (IndicateIndicator * indicator);
 
 
@@ -169,12 +169,11 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 /* A small little function to both clear the insides of a 
    value as well as the memory it itself uses. */
 static void 
-_g_value_free (gpointer data)
+_g_variant_unref (gpointer data)
 {
 	if (data == NULL) return;
-	GValue * value = (GValue*)data;
-	g_value_unset(value);
-	g_free(data);
+	GVariant * value = (GVariant*)data;
+	g_variant_unref(value);
 	return;
 }
 
@@ -187,7 +186,7 @@ indicate_indicator_init (IndicateIndicator * indicator)
 	priv->is_visible = FALSE;
 	priv->is_displayed = FALSE;
 
-	priv->properties = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, _g_value_free);
+	priv->properties = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, _g_variant_unref);
 
 	priv->server = indicate_server_ref_default();
 	priv->id = indicate_server_get_next_id(priv->server);
@@ -428,11 +427,8 @@ indicate_indicator_set_property (IndicateIndicator * indicator, const gchar * ke
 		return;
 	}
 
-	GValue strval = {0};
-	g_value_init(&strval, G_TYPE_STRING);
-	g_value_set_static_string(&strval, data);
-
-	return class->set_property(indicator, key, &strval);
+	GVariant * variant = g_variant_new_string(data);
+	return class->set_property(indicator, key, variant);
 }
 
 /**
@@ -479,7 +475,8 @@ indicate_indicator_set_property_int (IndicateIndicator * indicator, const gchar
 	g_value_init(&intval, G_TYPE_INT);
 	g_value_set_int(&intval, value);
 
-	return class->set_property(indicator, key, &intval);
+	GVariant * variant = g_variant_new_int32(value);
+	return class->set_property(indicator, key, variant);
 }
 
 /**
@@ -500,15 +497,12 @@ indicate_indicator_set_property_bool (IndicateIndicator * indicator, const gchar
 		return;
 	}
 
-	GValue boolval = {0};
-	g_value_init(&boolval, G_TYPE_BOOLEAN);
-	g_value_set_boolean(&boolval, value);
-
-	return class->set_property(indicator, key, &boolval);
+	GVariant * variant = g_variant_new_boolean(value);
+	return class->set_property(indicator, key, variant);
 }
 
 void
-indicate_indicator_set_property_value (IndicateIndicator * indicator, const gchar * key, GValue * value)
+indicate_indicator_set_property_variant (IndicateIndicator * indicator, const gchar * key, GVariant * value)
 {
 	IndicateIndicatorClass * class = INDICATE_INDICATOR_GET_CLASS(indicator);
 	if (class->set_property == NULL) {
@@ -536,12 +530,16 @@ indicate_indicator_get_property (IndicateIndicator * indicator, const gchar * ke
 		return NULL;
 	}
 
-	const GValue * val = class->get_property(indicator, key);
-	return g_value_get_string(val);
+	GVariant * val = class->get_property(indicator, key);
+	if (val == NULL) {
+		return NULL;
+	} else {
+		return g_variant_get_string(val, NULL);
+	}
 }
 
-const GValue *
-indicate_indicator_get_property_value (IndicateIndicator * indicator, const gchar * key)
+GVariant *
+indicate_indicator_get_property_variant (IndicateIndicator * indicator, const gchar * key)
 {
 	IndicateIndicatorClass * class = INDICATE_INDICATOR_GET_CLASS(indicator);
 	if (class->get_property == NULL) {
@@ -563,18 +561,18 @@ indicate_indicator_list_properties (IndicateIndicator * indicator)
 }
 
 static void
-set_property (IndicateIndicator * indicator, const gchar * key, const GValue * data)
+set_property (IndicateIndicator * indicator, const gchar * key, GVariant * data)
 {
 	g_return_if_fail(INDICATE_IS_INDICATOR(indicator));
 
 	IndicateIndicatorPrivate * priv = INDICATE_INDICATOR_GET_PRIVATE(indicator);
 
 	gchar * newkey = g_strdup(key);
-	GValue * newval = g_new0(GValue, 1);
-	g_value_init(newval, G_VALUE_TYPE(data));
-	g_value_copy(data, newval);
+	if (data != NULL) {
+		g_variant_ref(data);
+	}
 
-	g_hash_table_replace(priv->properties, newkey, newval);
+	g_hash_table_replace(priv->properties, newkey, data);
 
 	if (indicate_indicator_is_visible(indicator)) {
 		/* g_debug("Indicator property modified: %s", key); */
@@ -584,14 +582,14 @@ set_property (IndicateIndicator * indicator, const gchar * key, const GValue * d
 	return;
 }
 
-static const GValue *
+static GVariant *
 get_property (IndicateIndicator * indicator, const gchar * key)
 {
 	g_return_val_if_fail(INDICATE_IS_INDICATOR(indicator), NULL);
 
 	IndicateIndicatorPrivate * priv = INDICATE_INDICATOR_GET_PRIVATE(indicator);
 
-	return (const GValue *)g_hash_table_lookup(priv->properties, key);
+	return (GVariant *)g_hash_table_lookup(priv->properties, key);
 }
 
 static GPtrArray *
