@@ -111,46 +111,46 @@ struct _IndicateListenerClass {
 
 GType indicate_listener_get_type (void) G_GNUC_CONST;
 
-typedef void (*indicate_listener_get_property_value_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, const GValue * propertydata, gpointer data);
+typedef void (*indicate_listener_get_property_variant_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, GVariant * propertydata, gpointer data);
 typedef void (*indicate_listener_get_property_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, const gchar * propertydata, gpointer data);
 typedef void (*indicate_listener_get_property_time_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, const GTimeVal * propertydata, gpointer data);
 typedef void (*indicate_listener_get_property_int_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, gint propertydata, gpointer data);
 typedef void (*indicate_listener_get_property_bool_cb) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, gboolean propertydata, gpointer data);
-typedef void (*indicate_listener_get_server_property_cb) (IndicateListener * listener, IndicateListenerServer * server, gchar * value, gpointer data);
+typedef void (*indicate_listener_get_server_property_cb) (IndicateListener * listener, IndicateListenerServer * server, const gchar * value, gpointer data);
 typedef void (*indicate_listener_get_server_uint_property_cb) (IndicateListener * listener, IndicateListenerServer * server, guint value, gpointer data);
 
 /* Create a new listener */
 IndicateListener *    indicate_listener_new                (void);
 IndicateListener *    indicate_listener_ref_default        (void);
-void                  indicate_listener_get_property_value (IndicateListener * listener,
+void                  indicate_listener_get_property_variant (IndicateListener * listener,
                                                             IndicateListenerServer * server,
                                                             IndicateListenerIndicator * indicator,
                                                             gchar * property,
-                                                            indicate_listener_get_property_value_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, GVariant * propertydata, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_get_property       (IndicateListener * listener,
                                                             IndicateListenerServer * server,
                                                             IndicateListenerIndicator * indicator,
                                                             gchar * property,
-                                                            indicate_listener_get_property_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, const gchar * propertydata, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_get_property_time  (IndicateListener * listener,
                                                             IndicateListenerServer * server,
                                                             IndicateListenerIndicator * indicator,
                                                             gchar * property,
-                                                            indicate_listener_get_property_time_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, const GTimeVal * propertydata, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_get_property_int   (IndicateListener * listener,
                                                             IndicateListenerServer * server,
                                                             IndicateListenerIndicator * indicator,
                                                             gchar * property,
-                                                            indicate_listener_get_property_int_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, gint propertydata, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_get_property_bool  (IndicateListener * listener,
                                                             IndicateListenerServer * server,
                                                             IndicateListenerIndicator * indicator,
                                                             gchar * property,
-                                                            indicate_listener_get_property_bool_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, gboolean propertydata, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_display            (IndicateListener * listener,
                                                             IndicateListenerServer * server,
@@ -162,19 +162,19 @@ void                  indicate_listener_displayed          (IndicateListener * l
                                                             gboolean displayed);
 void                  indicate_listener_server_get_type    (IndicateListener * listener,
                                                             IndicateListenerServer * server,
-                                                            indicate_listener_get_server_property_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, const gchar * value, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_server_get_desktop (IndicateListener * listener,
                                                             IndicateListenerServer * server,
-                                                            indicate_listener_get_server_property_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, const gchar * value, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_server_get_count   (IndicateListener * listener,
                                                             IndicateListenerServer * server,
-                                                            indicate_listener_get_server_uint_property_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, guint value, gpointer data),
                                                             gpointer data);
 void                  indicate_listener_server_get_menu    (IndicateListener * listener,
                                                             IndicateListenerServer * server,
-                                                            indicate_listener_get_server_property_cb callback,
+                                                            void (*callback) (IndicateListener * listener, IndicateListenerServer * server, const gchar * value, gpointer data),
                                                             gpointer data);
 const gchar *         indicate_listener_server_get_dbusname      (IndicateListenerServer * server);
 guint                 indicate_listener_indicator_get_id         (IndicateListenerIndicator * indicator);
