@@ -112,7 +112,7 @@ typedef gboolean (*indicate_server_get_indicator_list_slot_t) (IndicateServer *
  * Return value: Whether the call was successful in getting the
  * properties requested.
  */
-typedef gboolean (*indicate_server_get_indicator_property_group_slot_t) (IndicateServer * server, guint id, GPtrArray * properties, gchar *** value, GError **error);
+typedef gboolean (*indicate_server_get_indicator_property_group_slot_t) (IndicateServer * server, guint id, const gchar ** properties, GVariant ** value, GError **error);
 
 /**
  * indicate_server_get_indicator_properties_slot_t:
@@ -192,16 +192,16 @@ struct _IndicateServerClass {
 	/* Virtual Functions */
 	gboolean (*get_indicator_count) (IndicateServer * server, guint * count, GError **error);
 	indicate_server_get_indicator_list_slot_t get_indicator_list;
-	gboolean (*get_indicator_property) (IndicateServer * server, guint id, gchar * property, GValue * value, GError **error);
+	gboolean (*get_indicator_property) (IndicateServer * server, guint id, gchar * property, GVariant ** value, GError **error);
 	indicate_server_get_indicator_property_group_slot_t get_indicator_property_group;
 	indicate_server_get_indicator_properties_slot_t get_indicator_properties;
 	gboolean (*show_indicator_to_user) (IndicateServer * server, guint id, guint timestamp, GError ** error);
-	gboolean (*indicator_displayed) (IndicateServer * server, gchar * sender, guint id, gboolean displayed, GError ** error);
+	gboolean (*indicator_displayed) (IndicateServer * server, const gchar * sender, guint id, gboolean displayed, GError ** error);
 	guint    (*get_next_id) (IndicateServer * server);
-	gboolean (*show_interest) (IndicateServer * server, gchar * sender, IndicateInterests interest);
-	gboolean (*remove_interest) (IndicateServer * server, gchar * sender, IndicateInterests interest);
+	gboolean (*show_interest) (IndicateServer * server, const gchar * sender, IndicateInterests interest);
+	gboolean (*remove_interest) (IndicateServer * server, const gchar * sender, IndicateInterests interest);
 	gboolean (*check_interest) (IndicateServer * server, IndicateInterests interest);
-	gboolean (*max_indicators_set) (IndicateServer * server, gchar * sender, gint max);
+	gboolean (*max_indicators_set) (IndicateServer * server, const gchar * sender, gint max);
 	gint     (*max_indicators_get) (IndicateServer * server);
 
 	/* Reserver for future use */
